@@ -1,13 +1,17 @@
 import logging
 import random
 import Pyro4
-from pyage.core.agent import AGENT
+from pyage.core.agent.agent import AGENT
 from pyage.core.inject import Inject
 
 logger = logging.getLogger(__name__)
 
+class Locator(object):
+    def get_neighbour(self, agent):
+        raise NotImplementedError()
 
-class Pyro4Locator(object):
+
+class Pyro4Locator(Locator):
     @Inject("ns_hostname")
     def __init__(self):
         super(Pyro4Locator, self).__init__()
@@ -28,8 +32,16 @@ class Pyro4Locator(object):
         return Pyro4.Proxy(random.choice(agents.values()))
 
 
-class ParentLocator(object):
+class ParentLocator(Locator):
     def get_neighbour(self, agent):
         siblings = list(agent.parent.get_agents())
+        #       logger.debug(len(siblings))
         siblings.remove(agent)
-        return random.choice(siblings)
\ No newline at end of file
+        return random.choice(siblings)
+
+
+class GridParentLocator(Locator):
+    def get_neighbour(self, agent):
+        siblings = list(agent.parent.get_agents())
+        index = siblings.index(agent)
+        return random.choice(siblings[index - 2:index] + siblings[index + 1:index + 3])
